@@ -1,6 +1,6 @@
 package Munin::Master::Node;
 
-# $Id: Node.pm 3271 2009-12-30 11:19:05Z janl $
+# $Id: Node.pm 3484 2010-04-14 18:37:51Z bldewolf $
 
 # This module is used by UpdateWorker to keep in touch with a node and
 # parse some of the output.
@@ -92,11 +92,12 @@ sub _run_starttls_if_required {
     # TLS should only be attempted if explicitly enabled. The default
     # value is therefore "disabled" (and not "auto" as before).
     my $tls_requirement = $config->{tls};
-    INFO "TLS set to \"$tls_requirement\".";
+    DEBUG "TLS set to \"$tls_requirement\".";
     return if $tls_requirement eq 'disabled';
+    my $logger = Log::Log4perl->get_logger("Munin::Master");
     $self->{tls} = Munin::Common::TLSClient->new({
         DEBUG        => $config->{debug},
-        logger       => \&logger,
+        logger       => sub { $logger->warn(@_) },
         read_fd      => fileno($self->{socket}),
         read_func    => sub { _node_read_single($self) },
         tls_ca_cert  => $config->{tls_ca_certificate},
@@ -105,8 +106,9 @@ sub _run_starttls_if_required {
         tls_priv     => $config->{tls_private_key},
         tls_vdepth   => $config->{tls_verify_depth},
         tls_verify   => $config->{tls_verify_certificate},
+        tls_match    => $config->{tls_match},
         write_fd     => fileno($self->{socket}),
-        write_func   => sub { _write_socket_single($self, @_) },
+        write_func   => sub { _node_write_single($self, @_) },
     });
 
     if (!$self->{tls}->start_tls()) {
